@@ -2,7 +2,7 @@
 import datetime
 from dataclasses import dataclass
 from enum import Enum
-from typing import Generator, List, Dict
+from typing import Generator, List, Dict, Optional
 from uuid import uuid4
 
 import pytz
@@ -10,15 +10,27 @@ import pytz
 from gcp_pilot.base import GoogleCloudPilotAPI, DiscoveryMixin, ResourceType
 
 
+class ResponseStatus(Enum):
+    # Predefined options to attendee response status
+    # Refs: <https://developers.google.com/calendar/api/v3/reference/events/update#attendees.responseStatus>
+    # pylint: disable=invalid-name
+    needs_action = "needsAction"
+    declined = "declined"
+    tentative = "tentative"
+    accepted = "accepted"
+
+
 @dataclass
 class Attendee:
     email: str
     optional: bool = False
+    response_status: ResponseStatus = None
 
     def as_data(self) -> Dict:
         return {
             "email": self.email,
             "optional": self.optional,
+            "responseStatus": self.response_status,
         }
 
 
@@ -40,6 +52,15 @@ class Color(Enum):
     # pylint: enable=invalid-name
 
 
+class SendUpdates(Enum):
+    # Predefined options to send updates on events.
+    # Refs: <https://developers.google.com/calendar/api/v3/reference/events/update#sendUpdates>
+    # pylint: disable=invalid-name
+    all = "all"
+    external_only = "externalOnly"
+    none = "none"
+
+
 class Calendar(DiscoveryMixin, GoogleCloudPilotAPI):
     _scopes = ["https://www.googleapis.com/auth/calendar"]
 
@@ -169,6 +190,7 @@ class Calendar(DiscoveryMixin, GoogleCloudPilotAPI):
         recurrence_amount: str = None,
         calendar_id: str = "primary",
         color: Color = None,
+        send_updates: SendUpdates = None,
     ) -> ResourceType:
         def _build_time_field(dt):
             if isinstance(start_at, datetime.datetime):
@@ -186,6 +208,7 @@ class Calendar(DiscoveryMixin, GoogleCloudPilotAPI):
             "description": description,
             "start": _build_time_field(dt=start_at),
             "end": _build_time_field(dt=end_at),
+            "sendUpdates": send_updates,
         }
 
         if color:
@@ -214,14 +237,17 @@ class Calendar(DiscoveryMixin, GoogleCloudPilotAPI):
     def get_events(
         self,
         calendar_id: str = "primary",
-        starts_at: datetime.date = None,
+        starts_at: Optional[datetime.date] = None,
+        ends_at: Optional[datetime.date] = None,
     ) -> Generator[ResourceType, None, None]:
         min_date = self._date_to_str(starts_at) if starts_at else None
+        max_date = self._date_to_str(ends_at) if ends_at else None
 
         page_size = 100
         params = dict(
             calendarId=calendar_id,
             timeMin=min_date,
+            timeMax=max_date,
             singleEvents=True,
         )
 
@@ -310,4 +336,6 @@ __all__ = (
     "Calendar",
     "Attendee",
     "Color",
+    "ResponseStatus",
+    "SendUpdates",
 )
